---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Replace the text below with the details of the issue you are facing.  
DO NOT simply erase the form and type a free-form response.**
-----

### Issue Summary

A summary of the issue and the browser/OS environment in which it occurs. If
suitable, include the steps required to reproduce the bug.

### Steps to Reproduce:

1. This is the first step
2. This is the second step
3. Further steps, etc.

Any other information you want to share that is relevant to the issue
being reported. Especially, why do you consider this to be a bug? What
do you expect to happen instead?

### Technical details:

* MathJax Version: 3.2
* Client OS: (e.g., Mac OS X 10.8.4)
* Browser: (e.g., Chrome 29.0.1547.57)

I am using the following MathJax configuration:

``` js
MathJax = {
...
};
```

and loading MathJax via

``` html
<script src="https://cdn.jsdelivr.net/npm/mathjax@3/es5/tex-mml-chtml.js"></script>
```

### Supporting information:

 * Please supply a link to a (live) minimal example page, when possible.
 * If your issue is with the display of the mathematics produced by MathJax, include a screen snapshot that illustrates the problem, when possible.
 * Check your browser console window for any error messages, and include them here.
 * Include the MathJax configuration you are using, and the script tag that loads MathJax itself.
